interface StyleUtilConfig {
    cacheEnabled?: boolean;
    stylePriority?: Array<'theme' | 'class' | 'custom'>;
    errorHandler?: (error: unknown, styleSheetHref?: string) => void;
}
/**
 * Merges styles from a specified theme, class, and any custom styles provided.
 *
 * @param themeName - The name of the theme to retrieve styles from (e.g., 'light', 'dark').
 * @param className - The class name(s) applied to the element for additional styling. Overrides theme styles.
 * @param customStyles - An object containing custom inline styles that will override both theme and class styles.
 * @param config - Configuration options to control caching, style source priority, and error handling.
 * @returns An object containing the merged styles with the specified precedence order.
 */
export declare function getMergedStyles(themeName: string, className: string | null, customStyles?: {
    [key: string]: string;
}, config?: StyleUtilConfig): {
    [key: string]: string;
};
export {};
